@@ -12,7 +12,6 @@
 #include "mozilla/CycleCollectedJSContext.h"
 #include "mozilla/ErrorNames.h"
 #include "mozilla/ModuleUtils.h"
-#include "mozilla/Result.h"
 #include "mozilla/ResultExtensions.h"
 #include "mozilla/Services.h"
 #include "mozilla/StaticPrefs_dom.h"
@@ -50,7 +49,7 @@ namespace mozilla::dom {
 namespace {
 
 static const uint32_t gSupportedRegistrarVersions[] = {
-    SERVICEWORKERREGISTRAR_VERSION, 8, 7, 6, 5, 4, 3, 2};
+    SERVICEWORKERREGISTRAR_VERSION, 10, 9, 8, 7, 6, 5, 4, 3, 2};
 
 static const uint32_t kInvalidGeneration = static_cast<uint32_t>(-1);
 
@@ -630,8 +629,41 @@ nsresult ServiceWorkerRegistrar::ReadData() {
 
     nsAutoCString line;
     switch (version) {
-      case SERVICEWORKERREGISTRAR_VERSION:
+      // to add new changes to the schema,
+      // we incremented SERVICEWORKERREGISTRAR_VERSION,
+      // added new changes on top of existing schema,
+      // and [[fallthrough]] to the previous one (version 10)
+      case SERVICEWORKERREGISTRAR_VERSION: {
+        nsAutoCString numberOfAttemptedActivationsStr;
+        GET_LINE(numberOfAttemptedActivationsStr);
+        int64_t numberOfAttemptedActivations =
+            numberOfAttemptedActivationsStr.ToInteger64(&rv);
+        if (NS_WARN_IF(NS_FAILED(rv))) {
+          return rv;
+        }
+        entry->mRegistration.numberOfAttemptedActivations() =
+            numberOfAttemptedActivations;
+        nsAutoCString isRegistrationBrokenStr;
+        GET_LINE(isRegistrationBrokenStr);
+        int64_t isBroken = isRegistrationBrokenStr.ToInteger64(&rv);
+        if (NS_WARN_IF(NS_FAILED(rv))) {
+          return rv;
+        }
+        entry->mRegistration.isBroken() = (isBroken != 0);
+        nsAutoCString cacheAPIIdStr;
+        GET_LINE(cacheAPIIdStr);
+        int64_t cacheAPIId = cacheAPIIdStr.ToInteger64(&rv);
+        if (NS_WARN_IF(NS_FAILED(rv))) {
+          return rv;
+        }
+        entry->mRegistration.cacheAPIId() = cacheAPIId;
+
         [[fallthrough]];
+      }
+
+      case 10:
+        [[fallthrough]];
+
       case 9: {
         rv = CreatePrincipalInfo(lineInputStream, entry->mRegistration);
         if (NS_WARN_IF(NS_FAILED(rv))) {
@@ -701,7 +733,11 @@ nsresult ServiceWorkerRegistrar::ReadData() {
 
         GET_LINE(entry->mRegistration.navigationPreloadState().headerValue());
 
-        if (version == SERVICEWORKERREGISTRAR_VERSION) {
+        // expando was introcuded in version 10
+        // but block was placed in version 9, since
+        // the expando is placed at the end of data
+        // and we cannot read it in case 10 block
+        if (version >= 10) {
           nsAutoCString expandoCountStr;
           GET_LINE(expandoCountStr);
           uint32_t expandoCount = expandoCountStr.ToInteger(&rv, 16);
@@ -1409,6 +1445,17 @@ nsresult ServiceWorkerRegistrar::WriteData(
     cInfo.attrs().CreateSuffix(suffix);
 
     buffer.Truncate();
+
+    buffer.AppendInt(static_cast<int32_t>(
+        data.mRegistration.numberOfAttemptedActivations()));
+    buffer.Append('\n');
+
+    buffer.AppendInt(static_cast<int32_t>(data.mRegistration.isBroken()));
+    buffer.Append('\n');
+
+    buffer.AppendInt(static_cast<int32_t>(data.mRegistration.cacheAPIId()));
+    buffer.Append('\n');
+
     buffer.Append(suffix.get());
     buffer.Append('\n');
 
