@@ -10,7 +10,6 @@
 // https://www.rfc-editor.org/rfc/rfc7540.txt
 
 #include "ASpdySession.h"
-#include "mozilla/Attributes.h"
 #include "mozilla/Queue.h"
 #include "mozilla/UniquePtr.h"
 #include "mozilla/WeakPtr.h"
@@ -655,6 +654,7 @@ class Http2Session final : public ASpdySession,
  private:
   TimeStamp mLastTRRResponseTime;  // Time of the last successful TRR response
   uint32_t mTrrStreams;
+  nsCString mTrrHost;
 
   // Whether we allow websockets, based on a pref
   bool mEnableWebsockets = false;
